@@ -13,7 +13,7 @@ GETS = {
     ),
     'devices': (
         'getByGroup', 'getByHostname', 'getById', 'getByIp', 'getByName',
-        'list', 'listGroups', 'rename',
+        'list', 'listGroups',
     ),
     'metrics': (
         'getLatest', 'getRange', 'list',
@@ -25,7 +25,7 @@ GETS = {
         'getByTime', 'getRange',
     ),
     'users': (
-        'getById', 'delete',
+        'getById', 'list',
     ),
 }
 
@@ -34,17 +34,17 @@ POSTS = {
         'pause', 'resume',
     ),
     'devices': (
-        'add', 'addGroup', 'delete',
+        'add', 'addGroup', 'delete', 'rename',
     ),
     'metrics': (
         'postback',
     ),
     'users': (
-        'add',
+        'add', 'delete',
     ),
 }
 
-API_VERSION = '1.3'
+API_VERSION = '1.4'
 BASE_URL = 'https://api.serverdensity.com/%(version)s/%(section)s/%(method)s'
 
 class SDApi(object):
@@ -75,6 +75,9 @@ class SDApi(object):
             'method': method,
         }
 
+        if self._name not in self._gets and self._name not in self._posts:
+            raise AttributeError(u'No section named %s' % (self._name,))
+
         if method in self._gets[self._name]:
             request = requests.get(url, params=params, auth=(self._username,
                 self._password))
@@ -82,7 +85,7 @@ class SDApi(object):
             request = requests.post(url, params=params, auth=(self._username,
                 self._password))
         else:
-            raise AttributeError(u'No method named %s' % (self._name,))
+            raise AttributeError(u'No method named %s' % (method,))
 
         response = json.loads(request.content)
         if response['status'] == 2:
